@@ -151,6 +151,7 @@ void server::registration(int id, modules::regmode_t mode)
 void server::activate(MappedRegistry *rr)
 {
 	linked_pointer<modules::sipwitch> cb = getModules();
+	logging(rr, "activating");
 
 	while(is(cb)) {
 		cb->activating(rr);
@@ -162,12 +163,30 @@ void server::expire(MappedRegistry *rr)
 {
 	linked_pointer<modules::sipwitch> cb = getModules();
 
+	logging(rr, "releasing");
+
 	while(is(cb)) {
 		cb->expiring(rr);
 		cb.next();
 	}
 }
 
+void server::logging(MappedRegistry *rr, const char *reason)
+{
+	time_t now;
+	struct tm *dt, hold;
+
+	time(&now);
+	dt = localtime_r(&now, &hold);
+	if(dt->tm_year < 1900)
+		dt->tm_year += 1900;
+
+	process::printlog("%s %s %04d-%02d-%02d %02d:%02d:%02d\n",
+		reason, rr->userid, 
+		dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+		dt->tm_hour, dt->tm_min, dt->tm_sec);
+}
+
 bool server::classify(rtpproxy::session *sid, rtpproxy::session *src, struct sockaddr *addr)
 {
 	linked_pointer<modules::sipwitch> cb = getModules();
@@ -809,6 +828,13 @@ void server::run(const char *user)
 		debug(9, "received request %s\n", cp);
 
         if(!stricmp(cp, "reload")) {
+			time(&now);
+			dt = localtime_r(&now, &hold);
+			if(dt->tm_year < 1900)
+				dt->tm_year += 1900;
+			process::printlog("server reloading %04d-%02d-%02d %02d:%02d:%02d\n",
+				dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+				dt->tm_hour, dt->tm_min, dt->tm_sec);
             reload(user);
             continue;
         }
@@ -864,7 +890,15 @@ invalid:
 		if(!stricmp(argv[0], "period")) {
 			if(argc != 2)
 				goto invalid;
-			service::period(atol(argv[1]));
+			if(service::period(atol(argv[1]))) {
+				time(&now);
+				dt = localtime_r(&now, &hold);
+				if(dt->tm_year < 1900)
+					dt->tm_year += 1900;
+				process::printlog("server period %04d-%02d-%02d %02d:%02d:%02d\n",
+					dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+					dt->tm_hour, dt->tm_min, dt->tm_sec);
+			}
 			continue;
 		}
 
@@ -888,6 +922,14 @@ invalid:
 				fputs(state, fp);
 				fclose(fp);
 			}
+			time(&now);
+			dt = localtime_r(&now, &hold);
+			if(dt->tm_year < 1900)
+				dt->tm_year += 1900;
+			process::printlog("state %s %04d-%02d-%02d %02d:%02d:%02d\n",
+				state, dt->tm_year, dt->tm_mon + 1, dt->tm_mday,
+				dt->tm_hour, dt->tm_min, dt->tm_sec);
+
 			process::errlog(NOTICE, "state changed to %s", state);
 			reload(user);
 			continue;
